@@ -1,17 +1,19 @@
 pub mod attributes;
 
 mod argument_parse;
-mod callable_trait_parse;
 mod contract_trait_parse;
 mod endpoint_parse;
 mod method_impl_parse;
 mod method_parse;
 mod parse_util;
 mod payable_parse;
+mod split_path;
+mod supertrait_parse;
 
 pub use argument_parse::*;
-pub use callable_trait_parse::*;
 pub use contract_trait_parse::*;
 pub use endpoint_parse::*;
 pub use method_parse::*;
 pub use payable_parse::*;
+pub use split_path::*;
+pub use supertrait_parse::*;
